@@ -896,6 +896,55 @@ class Visualization:
                 textExp.style.color = Visualization.CHANGED_COLOR
                 note2.activeSite.insert(note2.offset, textExp)
 
+            # lyrics
+            elif op[0] == "inslyric":
+                assert isinstance(op[1], AnnNote)
+                assert isinstance(op[2], AnnNote)
+                # color the modified note in both scores using Visualization.INSERTED_COLOR
+                note1 = score1.recurse().getElementById(op[1].general_note)
+                note1.style.color = Visualization.INSERTED_COLOR
+                textExp = m21.expressions.TextExpression("inserted lyric")
+                textExp.style.color = Visualization.INSERTED_COLOR
+                note1.activeSite.insert(note1.offset, textExp)
+
+                note2 = score2.recurse().getElementById(op[2].general_note)
+                note2.style.color = Visualization.INSERTED_COLOR
+                textExp = m21.expressions.TextExpression("inserted lyric")
+                textExp.style.color = Visualization.INSERTED_COLOR
+                note2.activeSite.insert(note2.offset, textExp)
+
+            elif op[0] == "dellyric":
+                assert isinstance(op[1], AnnNote)
+                assert isinstance(op[2], AnnNote)
+                # color the modified note in both scores using Visualization.DELETED_COLOR
+                note1 = score1.recurse().getElementById(op[1].general_note)
+                note1.style.color = Visualization.DELETED_COLOR
+                textExp = m21.expressions.TextExpression("deleted lyric")
+                textExp.style.color = Visualization.DELETED_COLOR
+                note1.activeSite.insert(note1.offset, textExp)
+
+                note2 = score2.recurse().getElementById(op[2].general_note)
+                note2.style.color = Visualization.DELETED_COLOR
+                textExp = m21.expressions.TextExpression("deleted lyric")
+                textExp.style.color = Visualization.DELETED_COLOR
+                note2.activeSite.insert(note2.offset, textExp)
+
+            elif op[0] == "editlyric":
+                assert isinstance(op[1], AnnNote)
+                assert isinstance(op[2], AnnNote)
+                # color the modified note (in both scores) using Visualization.CHANGED_COLOR
+                note1 = score1.recurse().getElementById(op[1].general_note)
+                note1.style.color = Visualization.CHANGED_COLOR
+                textExp = m21.expressions.TextExpression("changed lyric")
+                textExp.style.color = Visualization.CHANGED_COLOR
+                note1.activeSite.insert(note1.offset, textExp)
+
+                note2 = score2.recurse().getElementById(op[2].general_note)
+                note2.style.color = Visualization.CHANGED_COLOR
+                textExp = m21.expressions.TextExpression("changed lyric")
+                textExp.style.color = Visualization.CHANGED_COLOR
+                note2.activeSite.insert(note2.offset, textExp)
+
             else:
                 print(f"Annotation type {op[0]} not yet supported for visualization", file=sys.stderr)
 
